@@ -98,7 +98,7 @@ class HdDB:
             self.create_hd_tables()
             self.create_hd_database(org, db, len(dataframes))
             self.create_hd_fields(all_metadata)
-            self.create_hd_views(org, db)
+            self.create_hd_views()
         except duckdb.Error as e:
             raise QueryError(f"Error executing query: {e}")
 
@@ -213,11 +213,12 @@ class HdDB:
             fields_query = f'SELECT * FROM "{org}__{db}".hd_fields WHERE tbl = ?'
             fields = self.execute(fields_query, [tbl]).fetch_df()
 
-            # Convert DataFrames to JSON objects
+            # Convert all columns to string type first, then handle null values
+            data = data.astype(str)
             data_json = json.loads(
-                data.fillna("")
-                .replace({"nan": "", "NaN": "", "None": ""})
-                .to_json(orient="records")
+                data.replace({"nan": "", "NaN": "", "None": ""}).to_json(
+                    orient="records"
+                )
             )
             fields_json = fields.to_dict(orient="records")
 
@@ -943,11 +944,12 @@ class HdDB:
             logger.error(f"Error fetching tables: {e}")
             raise QueryError(f"Error fetching tables: {e}")
 
-    def create_hd_views(self, org: str, db: str):
+    def create_hd_views(self):
         try:
             self.execute("BEGIN TRANSACTION;")
 
-            create_query = f'CREATE TABLE "{org}__{db}".hd_views (id VARCHAR, user_table VARCHAR, type VARCHAR, config JSON);'
+            # Crear la tabla en el esquema actual
+            create_query = "CREATE TABLE hd_views (id VARCHAR, user_table VARCHAR, type VARCHAR, config JSON);"
             self.execute(create_query)
 
             self.execute("COMMIT;")
@@ -962,6 +964,23 @@ class HdDB:
         self, org: str, db: str, id: str, tbl: str, type: str, config: dict
     ):
         try:
+            # Verificar si existe la tabla hd_views
+            check_query = f"""
+                SELECT table_name 
+                FROM information_schema.tables 
+                WHERE table_schema = '{org}__{db}' 
+                AND table_name = 'hd_views'
+            """
+            result = self.execute(check_query).fetchone()
+
+            # Si no existe la tabla, crearla
+            if not result:
+                self.execute("BEGIN TRANSACTION;")
+                create_query = f'CREATE TABLE "{org}__{db}".hd_views (id VARCHAR, user_table VARCHAR, type VARCHAR, config JSON);'
+                self.execute(create_query)
+                self.execute("COMMIT;")
+
+            # Insertar el registro
             insert_query = f'INSERT INTO "{org}__{db}".hd_views (id, user_table, type, config) VALUES (?, ?, ?, ?);'
             self.execute(insert_query, [id, tbl, type, config])
         except duckdb.Error as e:
